==> eBUS_SDK_JAI_Ubuntu-18.04-x86_64-6.4.0-6670.zip: opt/jai/ebus_sdk/Ubuntu-18.04-x86_64/share/doc/sdk/class_i_pv_soft_device_g_e_v.js <==
var class_i_pv_soft_device_g_e_v =
[
    [ "~IPvSoftDeviceGEV", "class_i_pv_soft_device_g_e_v.html#a7db3bdb5ac82907527002b0ecdeb9e49", null ],
    [ "AddStream", "class_i_pv_soft_device_g_e_v.html#a22c9aaa5d1e971f9061ed78b6e98bddd", null ],
    [ "GetGenICamXMLFile", "class_i_pv_soft_device_g_e_v.html#a958d4ce1e77822e55f9ffbc5c6efb6ad", null ],
    [ "GetInfo", "class_i_pv_soft_device_g_e_v.html#a3cb6ad7cb23dff29036629a930c75e64", null ],
    [ "GetMessagingChannel", "class_i_pv_soft_device_g_e_v.html#adcbcc310bbce5c60e49f5a8240f2a922", null ],
    [ "GetRegisterMap", "class_i_pv_soft_device_g_e_v.html#a8e3d7edcde3bd43954cbf759b0ee3b2a", null ],
    [ "GetStatistics", "class_i_pv_soft_device_g_e_v.html#a3b202dfa91cd16665919e70fe054e470", null ],
    [ "RegisterEventSink", "class_i_pv_soft_device_g_e_v.html#a3df7a53d9c5c5939c48eac6a9c09cfe1", null ],
    [ "SetActionHandler", "class_i_pv_soft_device_g_e_v.html#af9bf35b851a0d77ff53006604f9cee0e", null ],
    [ "SetRTPProtocolEnabled", "class_i_pv_soft_device_g_e_v.html#ac29fe35b39fc8c13a02bf7c92a31d9e1", null ],
    [ "SetTCPTransportEnabled", "class_i_pv_soft_device_g_e_v.html#aadfedac75117c5502f2959889f78cc87", null ],
    [ "SetUserSetNotify", "class_i_pv_soft_device_g_e_v.html#a8806886473ed71e2a5483bfc1eee37ed", null ],
    [ "Start", "class_i_pv_soft_device_g_e_v.html#afdf328531adbc0ef50550ce6a44c4aba", null ],
    [ "Stop", "class_i_pv_soft_device_g_e_v.html#aecd06c1ca47d9ccda8cd1d8c6a2806e3", null ],
    [ "UnregisterEventSink", "class_i_pv_soft_device_g_e_v.html#accd0d2afc61a559f650a16afb79af5aa", null ],
    [ "code", "class_i_pv_soft_device_g_e_v.html#ae3a8972fd7dfac962568f97303ef1674", null ]
];

==> eBUS_SDK_JAI_Ubuntu-22.04-x86_64-6.4.0-6670.zip: opt/jai/ebus_sdk/Ubuntu-22.04-x86_64/share/doc/sdk/class_i_pv_soft_device_g_e_v.js <==
var class_i_pv_soft_device_g_e_v =
[
    [ "~IPvSoftDeviceGEV", "class_i_pv_soft_device_g_e_v.html#a7db3bdb5ac82907527002b0ecdeb9e49", null ],
    [ "AddStream", "class_i_pv_soft_device_g_e_v.html#a22c9aaa5d1e971f9061ed78b6e98bddd", null ],
    [ "GetGenICamXMLFile", "class_i_pv_soft_device_g_e_v.html#a958d4ce1e77822e55f9ffbc5c6efb6ad", null ],
    [ "GetInfo", "class_i_pv_soft_device_g_e_v.html#a3cb6ad7cb23dff29036629a930c75e64", null ],
    [ "GetMessagingChannel", "class_i_pv_soft_device_g_e_v.html#adcbcc310bbce5c60e49f5a8240f2a922", null ],
    [ "GetRegisterMap", "class_i_pv_soft_device_g_e_v.html#a8e3d7edcde3bd43954cbf759b0ee3b2a", null ],
    [ "GetStatistics", "class_i_pv_soft_device_g_e_v.html#a3b202dfa91cd16665919e70fe054e470", null ],
    [ "RegisterEventSink", "class_i_pv_soft_device_g_e_v.html#a3df7a53d9c5c5939c48eac6a9c09cfe1", null ],
    [ "SetActionHandler", "class_i_pv_soft_device_g_e_v.html#af9bf35b851a0d77ff53006604f9cee0e", null ],
    [ "SetRTPProtocolEnabled", "class_i_pv_soft_device_g_e_v.html#ac29fe35b39fc8c13a02bf7c92a31d9e1", null ],
    [ "SetTCPTransportEnabled", "class_i_pv_soft_device_g_e_v.html#aadfedac75117c5502f2959889f78cc87", null ],
    [ "SetUserSetCount", "class_i_pv_soft_device_g_e_v.html#a784159014cbf445ca3d59842e054fff4", null ],
    [ "SetUserSetNotify", "class_i_pv_soft_device_g_e_v.html#a8806886473ed71e2a5483bfc1eee37ed", null ],
    [ "Start", "class_i_pv_soft_device_g_e_v.html#afdf328531adbc0ef50550ce6a44c4aba", null ],
    [ "Stop", "class_i_pv_soft_device_g_e_v.html#aecd06c1ca47d9ccda8cd1d8c6a2806e3", null ],
    [ "UnregisterEventSink", "class_i_pv_soft_device_g_e_v.html#accd0d2afc61a559f650a16afb79af5aa", null ]
];
